@@ -36,35 +36,37 @@ plot.spdur <- function(x, type="sepplot", ci=TRUE, ...) {
   }
 }
 
-#'  Simulate and plot hazard function
-#'  
-#'  Given a set of values for the duration and risk equations, plot the shape of
-#'  estimated hazard function in respect to duration. Confidence intervals are 
-#'  provided through simulation.
-#'  
-#'  @param x An object of class \code{spdur}
-#'  @param t Time values at which to evaluate hazard function, e.g. \code{c(1:50)}.
-#'    Defaults to 1 through 1.2 * maximum duration value in data. 
-#'  @param ci Compute simulation-based confidence interval?
-#'  @param n Number of simulations to use for CI, defaults to 1,000. 
-#'  @param xvals A vector of values for the duration equation variables, in the 
-#'    same order as the duration equation in \code{x}. Defaults to means.
-#'  @param zvals A vector of values for the risk equation varialbes, in teh same
-#'    order as the risk equation in \code{x}. Defaults to means.
-#'  @param \dots Additional parameters passed to \code{\link{plot}}.
-#'    
-#'  @examples 
-#'  # Get model estimates
-#'  data(model.coups)
+#' Plot hazard function
 #' 
-#'  # Plot
-#'  plot_hazard(model.coups, ci = FALSE)
-#'  plot_hazard(model.coups, ci = TRUE)
-#'      
-#'  @importFrom MASS mvrnorm
-#'  @importFrom graphics lines plot
-#'  @importFrom stats quantile rnorm
-#'  @export
+#' \code{plot_hazard} plots the shape of estimated hazard function in respect 
+#' to duration, given a set of values for the duration and risk equations 
+#' covariates. Confidence intervals are provided through simulation.
+#' 
+#' @param x An object of class \code{spdur}
+#' @param t Time values at which to evaluate hazard function, e.g. \code{c(1:50)}.
+#'    Defaults to 1 through 1.2 * maximum duration value in data. 
+#' @param ci Compute simulation-based confidence interval?
+#' @param n Number of simulations to use for CI, defaults to 1,000. 
+#' @param xvals A vector of values for the duration equation variables, in the 
+#'    same order as the duration equation in \code{x}. Defaults to means.
+#' @param zvals A vector of values for the risk equation varialbes, in teh same
+#'    order as the risk equation in \code{x}. Defaults to means.
+#' @param \dots Additional parameters passed to \code{\link{plot}}.
+#' 
+#' @seealso \code{\link{separationplot.spdur}}
+#' 
+#' @examples 
+#' # Get model estimates
+#' data(model.coups)
+#' 
+#' # Plot
+#' plot_hazard(model.coups, ci = FALSE)
+#' plot_hazard(model.coups, ci = TRUE)
+#' 
+#' @importFrom MASS mvrnorm
+#' @importFrom graphics lines plot
+#' @importFrom stats quantile rnorm
+#' @export
 plot_hazard <- function(x, t = NULL, ci=TRUE, n=1000, xvals=NULL, zvals=NULL, ...) {
   
   # Set t vector if needed to 1.2 * max observed duration; lower limit is 1
@@ -80,12 +82,13 @@ plot_hazard <- function(x, t = NULL, ci=TRUE, n=1000, xvals=NULL, zvals=NULL, ..
   Z <- model.matrix(attr(x$mf.risk, 'terms'), data=x$mf.risk)
   
   # Extract coefficient point estimates
-  beta  <- x$coef[1:ncol(X)]
-  gamma <- x$coef[(ncol(X) + 1):(ncol(X) + ncol(Z))]
-  a     <- x$coef[ncol(X) + ncol(Z) + 1]
-  alpha <- exp(-a)
-  beta_vcv  <-x$vcv[1:ncol(X), 1:ncol(X)]
-  gamma_vcv <-x$vcv[(ncol(X) + 1):(ncol(X) + ncol(Z)), (ncol(X) + 1):(ncol(X) + ncol(Z))]
+  beta  <- coef(x, model = "duration")
+  gamma <- coef(x, model = "risk")
+  alpha <- coef(x, model = "distr")
+  alpha <- exp(-alpha)
+  beta_vcv  <- vcov(x, "duration")
+  gamma_vcv <- vcov(x, "risk")
+  alpha_vcv <- vcov(x, "distr")
   
   if (is.null(xvals)) {
     X_vals <- apply(X, 2, mean)		
@@ -102,7 +105,7 @@ plot_hazard <- function(x, t = NULL, ci=TRUE, n=1000, xvals=NULL, zvals=NULL, ..
   } else if (!length(zvals)==ncol(Z) && length(zvals)-ncol(Z)==-1) {
     stop("Incorrect length for zvals, did you forget 1 for intercept term?")			
   } else if (!length(zvals)==ncol(Z)) {
-    stop("Incorrect length for xvals")
+    stop("Incorrect length for zvals")
   } else {
     Z_vals <- zvals
   }
@@ -115,10 +118,15 @@ plot_hazard <- function(x, t = NULL, ci=TRUE, n=1000, xvals=NULL, zvals=NULL, ..
                out = NULL, dist = x$distr)
   
   if (ci==TRUE) {
+    Coef_smpl <- mvrnorm(n = n, mu = coef(x, "full"), Sigma = vcov(x, "full"))
     
-    Beta  <- mvrnorm(n = n, mu=beta,  Sigma=beta_vcv)	
-    Gamma <- mvrnorm(n = n, mu=gamma, Sigma=gamma_vcv)
-    A     <- rnorm(n = n, mean = a, sd = x$vcv[, "log(alpha)"]["log(alpha)"])
+    b_idx <- 1:x$n.terms$duration
+    g_idx <- (max(b_idx) + 1):(max(b_idx) + x$n.terms$risk)
+    a_idx <- (max(g_idx) + 1):ncol(Coef_smpl)
+    
+    Beta  <- Coef_smpl[, b_idx]
+    Gamma <- Coef_smpl[, g_idx]
+    A     <- Coef_smpl[, a_idx]
     Alpha <- exp(-A)
     
     lambda <- exp(-tcrossprod(X_vals, Beta))
